@@ -1,7 +1,7 @@
 use super::{arc::ArcBuffer, number::Number};
-use crate::type_information;
 use std::{cmp::max, str::from_utf8_unchecked};
 
+#[pen_ffi_macro::any_conv(crate = "crate")]
 #[repr(C)]
 #[derive(Clone, Debug, Default)]
 pub struct ByteString {
@@ -31,6 +31,7 @@ impl ByteString {
         self.len() == 0
     }
 
+    #[must_use]
     pub fn join(&self, other: &Self) -> Self {
         let mut buffer = ArcBuffer::new(self.len() + other.len());
 
@@ -41,6 +42,7 @@ impl ByteString {
     }
 
     // Indices are inclusive and start from 1.
+    #[must_use]
     pub fn char_slice(&self, start: Number, end: Number) -> Self {
         let start = f64::from(start);
         let end = f64::from(end);
@@ -105,8 +107,6 @@ impl From<Vec<u8>> for ByteString {
     }
 }
 
-type_information!(byte_string, crate::string::ByteString);
-
 #[cfg(test)]
 mod tests {
     use super::*;
